==> haskell-nonce-1.0.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-nonce.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nonce
version: 1.0.2
id: nonce-1.0.2-7sb9xV9gLCWCWWtYux6nAR
key: nonce-1.0.2-7sb9xV9gLCWCWWtYux6nAR
license: BSD3
copyright: (c) 2014 Prowdsponsor
maintainer: Prowdsponsor <opensource@prowdsponsor.com>
homepage: https://github.com/prowdsponsor/nonce
synopsis: Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.
    .
    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.
category: Cryptography
author: Felipe Lessa <felipe.lessa@prowdsponsor.com>
exposed: True
exposed-modules:
    Crypto.Nonce
abi: 3d48e8631911c251a4a02e8071adb2e4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/nonce-1.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/nonce-1.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/nonce-1.0.2
hs-libraries: HSnonce-1.0.2-7sb9xV9gLCWCWWtYux6nAR
depends:
    base-4.9.0.0 base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 cprng-aes-0.6.1-3CbgfLgcmw43AeNLkrIDhM
    crypto-random-0.0.9-AGk3IYpp9wLG9XHXf3BgaD
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html: /usr/share/doc/haskell-nonce/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nonce-1.0.2-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-nonce.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nonce
version: 1.0.2
id: nonce-1.0.2-1EkL7fu4kw4EKAkfUDmryE
key: nonce-1.0.2-1EkL7fu4kw4EKAkfUDmryE
license: BSD3
copyright: (c) 2014 Prowdsponsor
maintainer: Prowdsponsor <opensource@prowdsponsor.com>
homepage: https://github.com/prowdsponsor/nonce
synopsis: Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.
    .
    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.
category: Cryptography
author: Felipe Lessa <felipe.lessa@prowdsponsor.com>
exposed: True
exposed-modules:
    Crypto.Nonce
abi: 72100e3b0ea6e30a6f4b9bbc5674b327
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/nonce-1.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/nonce-1.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/nonce-1.0.2
hs-libraries: HSnonce-1.0.2-1EkL7fu4kw4EKAkfUDmryE
depends:
    base-4.9.0.0 base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 cprng-aes-0.6.1-4vIp9M79FFGDH3p3k7idwe
    crypto-random-0.0.9-Jxwl2P30S0cADnfhVJnwtl
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html: /usr/share/doc/haskell-nonce/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
